@@ -19,7 +19,7 @@ consistent_datatypes = {"numeric": ["bit", "smallmoney", "money", "int",
                         "date":
                             ["date", "datetimeoffset", "datetime2", "smalldatetime",
                              "timestamp", "datetime", "time", "year",
-                             "interval", "timestamp_ltz", "timestamp_ntz", "timestamp_tz"],
+                             "interval", "timestamp_ltz", "timestamp_ntz", "timestamp_tz", "text"],
                         "string":
                             ["string", "varchar", "varchar2", "char",
                              "bpchar", "text", "nchar", "nvarchar",
@@ -502,46 +502,39 @@ class Query:
                         consistent_vec = consistent_datatypes[where_condition.field.internalDataType.lower()]
                         if (
                                 where_condition.field.internalDataType.lower() == "numeric" or where_condition.field.internalDataType.lower() == "string") \
-                                and where_condition.field.sourceDataType.lower() not in consistent_vec:
+                                and where_condition.field.sourceDataType.lower() in consistent_vec:
                             # if internal and original data types are not consistent each other use this pattern
                             # aggregation column (original data type, to internal data type ) AS Alias
                             formatted_cond = field_with_agg + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ") " + operator + " " + formatted_value
-                        elif where_condition.field.internalDataType.lower() == "date" and where_condition.field.sourceDataType.lower() not in consistent_vec:
+                        elif where_condition.field.internalDataType.lower() == "date" and where_condition.field.sourceDataType.lower() in consistent_vec:
                             # if internal and original data types are not consistent each other use this pattern
                             # aggregation column (original data type, to internal data type, date_format YYYY-MM-DD ) AS Alias
                             if where_condition.field.sourceFormat is not None:
                                 formatted_cond = field_with_agg + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ", format " + where_condition.field.sourceFormat + ") " + operator + " " + formatted_value
                             else:
-                                formatted_cond = field_with_agg + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ", format YYYY-MM-DD" + ") " + operator + " " + formatted_value
-                        else:
-                            # else
-                            if formatted_value is not None and where_condition.direction is None:
-                                formatted_cond = field_with_agg + " " + operator + " " + str(formatted_value)
-                            elif formatted_value is None and where_condition.direction is not None:
-                                if isinstance(where_condition.direction, PeriodOperator):
-                                    direction = where_condition.direction.name
-                                else:
-                                    direction = where_condition.direction
+                                if formatted_value is not None:
+                                    formatted_cond = field_with_agg + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ") " + operator + " " + formatted_value
+                                elif formatted_value is None and where_condition.direction is not None:
+                                    if isinstance(where_condition.direction, PeriodOperator):
+                                        direction = where_condition.direction.name
+                                    else:
+                                        direction = where_condition.direction
 
-                                if where_condition.steps is not None and where_condition.interval is not None:
-                                    formatted_cond = field_with_agg + " " + operator + " " + where_condition.interval + " " + direction + " " + where_condition.steps
-                                elif where_condition.steps is not None and where_condition.interval is None:
-                                    formatted_cond = (
-                                            field_with_agg + " " + operator + " " + direction + " " + where_condition.steps
-                                    )
-                                elif where_condition.steps is None and where_condition.interval is not None:
-                                    formatted_cond = field_with_agg + " " + operator + " " + where_condition.interval + " " + direction
-                                else:
-                                    formatted_cond = field_with_agg + " " + operator + " " + direction
-                            elif where_condition.field.complexExpression is not None:
-                                if where_condition.field.alias is not None:
-                                    formatted_cond = where_condition.field.complexExpression + " AS " + where_condition.field.alias
-                                else:
-                                    formatted_cond = where_condition.field.complexExpression
-                            elif operator is not None:
-                                formatted_cond = field_with_agg + " " + operator
+                                    if where_condition.steps is not None and where_condition.interval is not None:
+                                        formatted_cond = field_with_agg + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ") " + operator + " " + where_condition.interval + " " + direction + " " + where_condition.steps
+                                    elif where_condition.steps is not None and where_condition.interval is None:
+                                        formatted_cond = (
+                                                field_with_agg + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ") " + operator + " " + direction + " " + where_condition.steps
+                                        )
+                                    elif where_condition.steps is None and where_condition.interval is not None:
+                                        formatted_cond = field_with_agg + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ") " + operator + " " + where_condition.interval + " " + direction
+                                    else:
+                                        formatted_cond = field_with_agg + " (" + where_condition.field.sourceDataType + ", to " + where_condition.field.internalDataType + ") " + operator + " " + direction
+                        elif where_condition.field.complexExpression is not None:
+                            if where_condition.field.alias is not None:
+                                formatted_cond = where_condition.field.complexExpression + " AS " + where_condition.field.alias
                             else:
-                                formatted_cond = field_with_agg
+                                formatted_cond = where_condition.field.complexExpression
 
                         conditions.append(formatted_cond)
             elif isinstance(where_condition, CompositeCondition):
