@@ -36,10 +36,17 @@ if __name__ == '__main__':
     # TEST SPELL OUT
     # smartquery spell_out
     sq = SmartQuery(queries=[Query(
-        fields=[Field(column="store_city", alias="Store City", internalDataType="STRING", sourceDataType="CLOB"),
-                Field(column="time_the_date", alias="Time", internalDataType="DATE", sourceDataType="TIME")],
-        where=[Condition(Field(column="time_the_date", alias="Time", internalDataType="DATE", sourceDataType="TIME"),
-                         operator="FROM", direction="NEXT", steps="2", interval="time_quarter")],
+        fields=[Field(column="store_city", alias="Store City", internalDataType="STRING", sourceDataType="TEXT"),
+                Field(column="time_the_date", alias="Time", internalDataType="DATE", sourceDataType="TEXT")],
+        where=[Condition(Field(column="time_the_date", aggregation="MONTH", alias="Time", internalDataType="DATE", sourceDataType="TEXT"),
+                         operator="FROM", direction="NEXT", steps="2"),
+               Condition(Field(column="time_the_date", aggregation="MONTH", alias="Time", internalDataType="DATE",
+                               sourceDataType="TEXT"),
+                         operator="FROM", value=["2022"]),
+               Condition(Field(column="units shipped", aggregation="MAX", alias="max_units_shipped", internalDataType="NUMERIC",
+                               sourceDataType="REAL"),
+                         operator="GOE", value=["100"])
+               ],
         orderBy=[Sorting(field="Store City", order=SQLSorting.DESC),
                  Sorting(field="Time", order=SQLSorting.DESC)],
         limit=8,
